==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property convert608To708 If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708. 708 data present in the source content will be discarded.
 * @property scte20Detection Set to “auto” to handle streams with intermittent and/or non-aligned SCTE-20 and Embedded captions.
 * @property source608ChannelNumber Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
 */
public data class
ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings(
    public val convert608To708: String? = null,
    public val scte20Detection: String? = null,
    public val source608ChannelNumber: Int? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings):
            ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings =
            ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings(
                convert608To708 = javaType.convert608To708().map({ args0 -> args0 }).orElse(null),
                scte20Detection = javaType.scte20Detection().map({ args0 -> args0 }).orElse(null),
                source608ChannelNumber = javaType.source608ChannelNumber().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/outputs/ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property convert608To708 If upconvert, 608 data is both passed through via the “608 compatibility bytes” fields of the 708 wrapper as well as translated into 708. 708 data present in the source content will be discarded.
 * @property scte20Detection Set to “auto” to handle streams with intermittent and/or non-aligned SCTE-20 and Embedded captions.
 * @property source608ChannelNumber Specifies the 608/708 channel number within the video track from which to extract captions. Unused for passthrough.
 */
public data class
ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings(
    public val convert608To708: String? = null,
    public val scte20Detection: String? = null,
    public val source608ChannelNumber: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.medialive.outputs.ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings): ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings =
            ChannelInputAttachmentInputSettingsCaptionSelectorSelectorSettingsEmbeddedSourceSettings(
                convert608To708 = javaType.convert608To708().map({ args0 -> args0 }).orElse(null),
                scte20Detection = javaType.scte20Detection().map({ args0 -> args0 }).orElse(null),
                source608ChannelNumber = javaType.source608ChannelNumber().map({ args0 -> args0 }).orElse(null),
            )
    }
}
